@@ -1,4 +1,5 @@
-/*
+/*      $Id: misc.c,v 1.46 2004/08/22 22:18:50 olivier Exp $
+ 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
         the Free Software Foundation; either version 2, or (at your option)
@@ -14,7 +15,7 @@
         Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  
         oroborus - (c) 2001 Ken Lynch
-        xfwm4    - (c) 2002-2003 Olivier Fourdan
+        xfwm4    - (c) 2002-2004 Olivier Fourdan
  
  */
 
@@ -22,55 +23,50 @@
 #include <config.h>
 #endif
 
-#ifdef GDK_MULTIHEAD_SAFE
-#undef GDK_MULTIHEAD_SAFE
-#endif
-
+#include <X11/Xlib.h>
+#include <X11/Xutil.h>
+#include <X11/Xmd.h>
 #include <glib.h>
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
 #include <gdk/gdkx.h>
-#include <X11/Xlib.h>
-#include <X11/Xutil.h>
-#include <X11/Xmd.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <sys/types.h>
 #include <unistd.h>
-#include <libxfce4util/debug.h>
-#include <libxfcegui4/xinerama.h>
+#include <libxfce4util/libxfce4util.h> 
 
-#include "main.h"
+#include "display.h"
+#include "screen.h"
+#include "mywindow.h"
 #include "client.h"
 #include "misc.h"
 
-static int xgrabcount = 0;
-
 void
-getMouseXY (Window w, int *x2, int *y2)
+getMouseXY (ScreenInfo *screen_info, Window w, int *x2, int *y2)
 {
     Window w1, w2;
     gint x1, y1, m;
 
     TRACE ("entering getMouseXY");
 
-    XQueryPointer (dpy, w, &w1, &w2, &x1, &y1, x2, y2, &m);
+    XQueryPointer (myScreenGetXDisplay (screen_info), w, &w1, &w2, &x1, &y1, x2, y2, &m);
 }
 
 Window
-getMouseWindow (Window w)
+getMouseWindow (ScreenInfo *screen_info, Window w)
 {
     Window w1, w2;
     int x1, y1, x2, y2, m;
 
     TRACE ("entering getMouseWindow");
 
-    XQueryPointer (dpy, w, &w1, &w2, &x1, &y1, &x2, &y2, &m);
+    XQueryPointer (myScreenGetXDisplay (screen_info), w, &w1, &w2, &x1, &y1, &x2, &y2, &m);
     return w2;
 }
 
 GC
-createGC (Colormap cmap, char *col, int func, XFontStruct * font,
+createGC (ScreenInfo *screen_info, char *col, int func, XFontStruct * font,
     int line_width, gboolean inc_sw)
 {
     XGCValues gv;
@@ -82,7 +78,7 @@ createGC (Colormap cmap, char *col, int func, XFontStruct * font,
     TRACE ("color=%s", col);
 
     mask = GCForeground | GCFunction;
-    XAllocNamedColor (dpy, cmap, col, &xc1, &xc2);
+    XAllocNamedColor (myScreenGetXDisplay (screen_info), screen_info->cmap, col, &xc1, &xc2);
     gv.foreground = xc2.pixel;
     gv.function = func;
     if (font)
@@ -100,12 +96,12 @@ createGC (Colormap cmap, char *col, int func, XFontStruct * font,
         gv.line_width = line_width;
         mask = mask | GCLineWidth;
     }
-    gc = XCreateGC (dpy, XDefaultRootWindow (dpy), mask, &gv);
+    gc = XCreateGC (myScreenGetXDisplay (screen_info), screen_info->xroot, mask, &gv);
     return gc;
 }
 
 void
-sendClientMessage (Window w, Atom a, Atom x, Time timestamp)
+sendClientMessage (ScreenInfo *screen_info, Window w, Atom a, Atom x, Time timestamp)
 {
     XClientMessageEvent ev;
 
@@ -117,54 +113,28 @@ sendClientMessage (Window w, Atom a, Atom x, Time timestamp)
     ev.format = 32;
     ev.data.l[0] = x;
     ev.data.l[1] = timestamp;
-    XSendEvent (dpy, w, FALSE, 0L, (XEvent *)&ev);
+    XSendEvent (myScreenGetXDisplay (screen_info), w, FALSE, 0L, (XEvent *)&ev);
 }
 
-void
-MyXGrabServer (void)
-{
-    DBG ("entering MyXGrabServer");
-    if (xgrabcount == 0)
-    {
-        DBG ("grabbing server");
-        XGrabServer (dpy);
-    }
-    xgrabcount++;
-    DBG ("grabs : %i", xgrabcount);
-}
-
-void
-MyXUngrabServer (void)
-{
-    DBG ("entering MyXUngrabServer");
-    if (--xgrabcount < 0)       /* should never happen */
-    {
-        xgrabcount = 0;
-    }
-    if (xgrabcount == 0)
-    {
-        DBG ("ungrabbing server");
-        XUngrabServer (dpy);
-        XFlush (dpy);
-    }
-    DBG ("grabs : %i", xgrabcount);
-}
 /*
  * it's safer to grab the display before calling this routine
  * Returns true if the given window is present and mapped on root 
  */
 gboolean
-MyCheckWindow(Window w)
+checkWindowOnRoot(ScreenInfo *screen_info, Window w)
 {
+    DisplayInfo *display_info = NULL;
     Window dummy_root, parent;
     Window *wins = NULL;
     unsigned int count;
     Status test;
     
+    g_return_val_if_fail (screen_info != NULL, FALSE);
     g_return_val_if_fail (w != None, FALSE);
 
+    display_info = screen_info->display_info;
     gdk_error_trap_push ();
-    test = XQueryTree(dpy, w, &dummy_root, &parent, &wins, &count);
+    test = XQueryTree(display_info->dpy, w, &dummy_root, &parent, &wins, &count);
     if (wins)
     {
         XFree (wins);
@@ -172,51 +142,29 @@ MyCheckWindow(Window w)
     return (!gdk_error_trap_pop () && (test != 0) && (dummy_root == parent));
 }
 
-Window
-setTmpEventWin (int x, int y, unsigned int w, unsigned int h, long eventmask)
-{
-    Window win;
-    XSetWindowAttributes attributes;
-
-    attributes.event_mask = eventmask;
-    attributes.override_redirect = TRUE;
-    win = XCreateWindow (dpy, root, x, y, w, h, 0, 0, 
-                         InputOnly, CopyFromParent,
-                         CWEventMask | CWOverrideRedirect, &attributes);
-    XMapRaised (dpy, win);
-    XFlush (dpy);
-    return (win);
-}
-
 void
-removeTmpEventWin (Window w)
+placeSidewalks(ScreenInfo *screen_info, gboolean activate)
 {
-    XDestroyWindow (dpy, w);
-}
-
-void
-placeSidewalks(gboolean activate)
-{
-    g_return_if_fail (sidewalk[0] != None);
-    g_return_if_fail (sidewalk[1] != None);
+    g_return_if_fail (MYWINDOW_XWINDOW (screen_info->sidewalk[0]) != None);
+    g_return_if_fail (MYWINDOW_XWINDOW (screen_info->sidewalk[1]) != None);
 
     if (activate)
     {
-        XMoveResizeWindow(dpy, sidewalk[0], 
-                          0, 0,
-                          1, MyDisplayFullHeight (dpy, screen));
-        XMoveResizeWindow(dpy, sidewalk[1],
-                          MyDisplayFullWidth (dpy, screen) - 1, 0, 
-                          1, MyDisplayFullHeight (dpy, screen));
+        xfwmWindowShow (&screen_info->sidewalk[0], 
+                      0, 0,
+                      1, gdk_screen_get_height (screen_info->gscr), FALSE);
+        xfwmWindowShow (&screen_info->sidewalk[1],
+                      gdk_screen_get_width (screen_info->gscr) - 1, 0, 
+                      1, gdk_screen_get_height (screen_info->gscr), FALSE);
     }
     else
     {
         /* Place the windows off screen */
-        XMoveResizeWindow(dpy, sidewalk[0], 
-                          -1, 0,
-                          1, MyDisplayFullHeight (dpy, screen));
-        XMoveResizeWindow(dpy, sidewalk[1],
-                          MyDisplayFullWidth (dpy, screen), 0, 
-                          1, MyDisplayFullHeight (dpy, screen));
+        xfwmWindowShow (&screen_info->sidewalk[0], 
+                      -1, 0,
+                       1, gdk_screen_get_height (screen_info->gscr), FALSE);
+        xfwmWindowShow (&screen_info->sidewalk[1],
+                      gdk_screen_get_width (screen_info->gscr), 0, 
+                      1, gdk_screen_get_height (screen_info->gscr), FALSE);
     }
 }
